@@ -16,9 +16,9 @@ use Zing::Daemon;
 use FlightRecorder;
 use File::Spec;
 
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
-our $name = 'zing <{command}> <{app}> [options]';
+our $name = 'zing <{command}> [<{app}>] [options]';
 
 # METHODS
 
