@@ -13,7 +13,7 @@ use Data::Object::ClassHas;
 
 extends 'Zing::Process';
 
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 # ATTRIBUTES
 
@@ -69,7 +69,9 @@ Process Implementation
 
   my $zang = Zing::Zang->new(
     on_perform => sub {
-      shift->{performed}++
+      my ($self) = @_;
+
+      $self->{performed}++
     }
   );
 
